@@ -111,6 +111,12 @@ class QueryHistoryTradesReq:
     end_time: datetime.datetime = None
 
 
+@aztdataclass(proto.QryHisAccReq, adj_time=dict(settlement_date="%Y%m%d-%H:%M:%S.%f"))
+class QryHisAccReq:
+    account: str = None
+    settlement_date: datetime.datetime = None
+
+
 # 委托订单请求
 @aztdataclass(proto.PlaceOrder, price_dec="price_decimal_place", adj_price=["order_price", "discretion_price"],
               adj_time=dict(send_time=["%Y%m%d-%H:%M:%S.%f", "%Y%m%d-%H:%M:%S"]))
