@@ -67,13 +67,19 @@ class AztVeApiOld(CVexchangeTraderApi):
     # ------ QueryHistoryOrdersReq ------
     def QueryHistoryOrdersReq(self, req: api_struct.QueryHistoryOrdersReq, sync=False, timeout=3):
         self._verify_logined()
-        return self._sync_async_switch(sync, timeout, super().QueryHistoryOrdersReq, (req.__py2proto__(),))
+        req_proto = req.__py2proto__()
+        azt_logger.debug("发送参数：")
+        azt_logger.debug(req_proto)
+        return self._sync_async_switch(sync, timeout, super().QueryHistoryOrdersReq, (req_proto,))
 
     # ------ QueryHistoryTradesReq ------
     def QueryHistoryTradesReq(self, req: api_struct.QueryHistoryTradesReq, sync=False, timeout=3):
         self._verify_logined()
         return self._sync_async_switch(sync, timeout, super().QueryHistoryTradesReq, (req.__py2proto__(),))
 
+    def QueryHistoryAccReq(self, req:api_struct.QryHisAccReq,sync=False,timeout=3):
+        return self._sync_async_switch(sync, timeout, super().QueryHistoryAccReq, (req.__py2proto__(),))
+
     # ------ PlaceOrder ------
     def PlaceOrder(self, req: api_struct.PlaceOrder):
         self._verify_logined()
